pub struct AccountDef {
pub name: String,
pub discriminator: Vec<u8>,
}Fields
name: Stringdiscriminator: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for AccountDef
impl BorshDeserialize for AccountDef
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AccountDef
impl BorshSerialize for AccountDef
Sourceimpl Clone for AccountDef
impl Clone for AccountDef
Sourcefn clone(&self) -> AccountDef
fn clone(&self) -> AccountDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountDef
impl Debug for AccountDef
Sourceimpl<'de> Deserialize<'de> for AccountDef
impl<'de> Deserialize<'de> for AccountDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more