pub struct AccountDependency {
pub account_name: String,
pub depends_on: Vec<String>,
pub is_pda: bool,
pub is_signer: bool,
pub is_mut: bool,
pub must_be_initialized: bool,
pub initialization_order: u8,
}Fields
account_name: Stringdepends_on: Vec<String>is_pda: boolis_signer: boolis_mut: boolmust_be_initialized: boolinitialization_order: u8Trait Implementations
Sourceimpl BorshDeserialize for AccountDependency
impl BorshDeserialize for AccountDependency
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AccountDependency
impl BorshSerialize for AccountDependency
Sourceimpl Clone for AccountDependency
impl Clone for AccountDependency
Sourcefn clone(&self) -> AccountDependency
fn clone(&self) -> AccountDependency
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AccountDependency
impl RefUnwindSafe for AccountDependency
impl Send for AccountDependency
impl Sync for AccountDependency
impl Unpin for AccountDependency
impl UnwindSafe for AccountDependency