pub struct ArgumentDef {
pub name: String,
pub arg_type: IdlType,
}Fields
name: Stringarg_type: IdlTypeTrait Implementations
Sourceimpl BorshDeserialize for ArgumentDef
impl BorshDeserialize for ArgumentDef
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ArgumentDef
impl BorshSerialize for ArgumentDef
Sourceimpl Clone for ArgumentDef
impl Clone for ArgumentDef
Sourcefn clone(&self) -> ArgumentDef
fn clone(&self) -> ArgumentDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentDef
impl Debug for ArgumentDef
Sourceimpl<'de> Deserialize<'de> for ArgumentDef
impl<'de> Deserialize<'de> for ArgumentDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more