pub struct ConstantDef {
pub name: String,
pub constant_type: String,
pub value: String,
}Fields
name: Stringconstant_type: Stringvalue: StringTrait Implementations
Sourceimpl BorshDeserialize for ConstantDef
impl BorshDeserialize for ConstantDef
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ConstantDef
impl BorshSerialize for ConstantDef
Sourceimpl Clone for ConstantDef
impl Clone for ConstantDef
Sourcefn clone(&self) -> ConstantDef
fn clone(&self) -> ConstantDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstantDef
impl Debug for ConstantDef
Sourceimpl<'de> Deserialize<'de> for ConstantDef
impl<'de> Deserialize<'de> for ConstantDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more