pub struct EnumVariant {
pub name: String,
pub fields: Option<Vec<FieldDef>>,
}Fields
name: Stringfields: Option<Vec<FieldDef>>Trait Implementations
Sourceimpl BorshDeserialize for EnumVariant
impl BorshDeserialize for EnumVariant
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EnumVariant
impl BorshSerialize for EnumVariant
Sourceimpl Clone for EnumVariant
impl Clone for EnumVariant
Sourcefn clone(&self) -> EnumVariant
fn clone(&self) -> EnumVariant
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnumVariant
impl Debug for EnumVariant
Sourceimpl<'de> Deserialize<'de> for EnumVariant
impl<'de> Deserialize<'de> for EnumVariant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more