pub struct ErrorDef {
pub code: u32,
pub name: String,
pub msg: String,
}Fields
code: u32name: Stringmsg: StringTrait Implementations
Sourceimpl BorshDeserialize for ErrorDef
impl BorshDeserialize for ErrorDef
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ErrorDef
impl BorshSerialize for ErrorDef
Sourceimpl<'de> Deserialize<'de> for ErrorDef
impl<'de> Deserialize<'de> for ErrorDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more