pub struct IdlAccountItem {
pub name: String,
pub is_mut: bool,
pub is_signer: bool,
pub is_optional: bool,
pub docs: Vec<String>,
pub pda: Option<IdlPda>,
}Fields
name: Stringis_mut: boolis_signer: boolis_optional: booldocs: Vec<String>pda: Option<IdlPda>Trait Implementations
Sourceimpl BorshDeserialize for IdlAccountItem
impl BorshDeserialize for IdlAccountItem
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlAccountItem
impl BorshSerialize for IdlAccountItem
Sourceimpl Clone for IdlAccountItem
impl Clone for IdlAccountItem
Sourcefn clone(&self) -> IdlAccountItem
fn clone(&self) -> IdlAccountItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlAccountItem
impl Debug for IdlAccountItem
Sourceimpl<'de> Deserialize<'de> for IdlAccountItem
impl<'de> Deserialize<'de> for IdlAccountItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more