pub struct IdlConstant {
pub name: String,
pub constant_type: String,
pub value: String,
}Fields
name: Stringconstant_type: Stringvalue: StringTrait Implementations
Sourceimpl BorshDeserialize for IdlConstant
impl BorshDeserialize for IdlConstant
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlConstant
impl BorshSerialize for IdlConstant
Sourceimpl Clone for IdlConstant
impl Clone for IdlConstant
Sourcefn clone(&self) -> IdlConstant
fn clone(&self) -> IdlConstant
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlConstant
impl Debug for IdlConstant
Sourceimpl<'de> Deserialize<'de> for IdlConstant
impl<'de> Deserialize<'de> for IdlConstant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more