pub struct IdlInstruction {
pub name: String,
pub accounts: Vec<IdlAccountItem>,
pub args: Vec<IdlField>,
pub docs: Vec<String>,
}Fields
name: Stringaccounts: Vec<IdlAccountItem>args: Vec<IdlField>docs: Vec<String>Trait Implementations
Sourceimpl BorshDeserialize for IdlInstruction
impl BorshDeserialize for IdlInstruction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlInstruction
impl BorshSerialize for IdlInstruction
Sourceimpl Clone for IdlInstruction
impl Clone for IdlInstruction
Sourcefn clone(&self) -> IdlInstruction
fn clone(&self) -> IdlInstruction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlInstruction
impl Debug for IdlInstruction
Sourceimpl<'de> Deserialize<'de> for IdlInstruction
impl<'de> Deserialize<'de> for IdlInstruction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more