pub struct IdlMetadata {
pub name: String,
pub version: String,
pub spec: String,
pub description: String,
}Fields
name: Stringversion: Stringspec: Stringdescription: StringTrait Implementations
Sourceimpl BorshDeserialize for IdlMetadata
impl BorshDeserialize for IdlMetadata
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlMetadata
impl BorshSerialize for IdlMetadata
Sourceimpl Clone for IdlMetadata
impl Clone for IdlMetadata
Sourcefn clone(&self) -> IdlMetadata
fn clone(&self) -> IdlMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlMetadata
impl Debug for IdlMetadata
Sourceimpl Default for IdlMetadata
impl Default for IdlMetadata
Sourcefn default() -> IdlMetadata
fn default() -> IdlMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for IdlMetadata
impl<'de> Deserialize<'de> for IdlMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more