pub struct ParsedIdl {
pub address: String,
pub metadata: IdlMetadata,
pub instructions: Vec<Instruction>,
pub accounts: Vec<AccountDef>,
pub types: Vec<TypeDef>,
pub errors: Vec<ErrorDef>,
pub constants: Vec<ConstantDef>,
pub events: Vec<EventDef>,
}Fields
address: Stringmetadata: IdlMetadatainstructions: Vec<Instruction>accounts: Vec<AccountDef>types: Vec<TypeDef>errors: Vec<ErrorDef>constants: Vec<ConstantDef>events: Vec<EventDef>Trait Implementations
Sourceimpl BorshDeserialize for ParsedIdl
impl BorshDeserialize for ParsedIdl
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ParsedIdl
impl BorshSerialize for ParsedIdl
Sourceimpl<'de> Deserialize<'de> for ParsedIdl
impl<'de> Deserialize<'de> for ParsedIdl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more