pub struct SeedComponent {
pub seed_type: SeedType,
pub value: String,
}Fields
seed_type: SeedTypevalue: StringTrait Implementations
Sourceimpl BorshDeserialize for SeedComponent
impl BorshDeserialize for SeedComponent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SeedComponent
impl BorshSerialize for SeedComponent
Sourceimpl Clone for SeedComponent
impl Clone for SeedComponent
Sourcefn clone(&self) -> SeedComponent
fn clone(&self) -> SeedComponent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SeedComponent
impl RefUnwindSafe for SeedComponent
impl Send for SeedComponent
impl Sync for SeedComponent
impl Unpin for SeedComponent
impl UnwindSafe for SeedComponent