pub struct TestArgumentValue {
pub argument_name: String,
pub value_type: TestValueType,
}Fields
argument_name: Stringvalue_type: TestValueTypeTrait Implementations
Sourceimpl BorshDeserialize for TestArgumentValue
impl BorshDeserialize for TestArgumentValue
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TestArgumentValue
impl BorshSerialize for TestArgumentValue
Sourceimpl Clone for TestArgumentValue
impl Clone for TestArgumentValue
Sourcefn clone(&self) -> TestArgumentValue
fn clone(&self) -> TestArgumentValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestArgumentValue
impl Debug for TestArgumentValue
Sourceimpl<'de> Deserialize<'de> for TestArgumentValue
impl<'de> Deserialize<'de> for TestArgumentValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more